set SEARCH_PATH to vhist_stage;
CREATE TABLE IF NOT EXISTS nodes
(
    node_name varchar(128),
    node_id int,
    node_state varchar(128),
    node_address varchar(80),
    node_address_family varchar(10),
    export_address varchar(8192),
    export_address_family varchar(10),
    catalog_path varchar(8192),
    node_type varchar(9),
    is_ephemeral boolean,
    standing_in_for varchar(128),
    node_down_since timestamptz,
	batch_id integer
);
CREATE TABLE IF NOT EXISTS users
(
    user_id int,
    user_name varchar(128),
    is_super_user boolean,
    profile_name varchar(128),
    is_locked boolean,
    lock_time timestamptz,
    resource_pool varchar(128),
    memory_cap_kb varchar(20),
    temp_space_cap_kb varchar(20),
    run_time_cap varchar(63),
    all_roles varchar(8192),
    default_roles varchar(8192),
    search_path varchar(128),
	batch_id integer
);
CREATE TABLE IF NOT EXISTS load_streams
(
    session_id varchar(128),
    transaction_id int,
    statement_id int,
    stream_name varchar(128),
    schema_name varchar(128),
    table_id int,
    table_name varchar(128),
    load_start varchar(63),
    load_duration_ms numeric(54,0),
    is_executing boolean,
    accepted_row_count int,
    rejected_row_count int,
    read_bytes int,
    input_file_size_bytes int,
    parse_complete_percent int,
    unsorted_row_count int,
    sorted_row_count int,
    sort_complete_percent int,
	batch_id integer
);
CREATE TABLE IF NOT EXISTS disk_storage
(
    node_name varchar(128),
    storage_path varchar(8192),
    storage_usage varchar(8192),
    rank int,
    throughput int,
    latency int,
    storage_status varchar(80),
    disk_block_size_bytes int,
    disk_space_used_blocks int,
    disk_space_used_mb int,
    disk_space_free_blocks int,
    disk_space_free_mb int,
    disk_space_free_percent varchar(80),
load_timestamp timestamp,
	batch_id integer
);
CREATE TABLE IF NOT EXISTS projection_storage
(
    node_name varchar(128),
    projection_id int,
    projection_name varchar(128),
    projection_schema varchar(128),
    projection_column_count int,
    row_count int,
    used_bytes int,
    wos_row_count int,
    wos_used_bytes int,
    ros_row_count int,
    ros_used_bytes int,
    ros_count int,
    anchor_table_name varchar(128),
    anchor_table_schema varchar(128),
    anchor_table_id int,
load_timestamp timestamp,
	batch_id integer
);
CREATE TABLE IF NOT EXISTS projection_usage
(
    query_start_timestamp timestamptz,
    node_name varchar(128),
    user_name varchar(128),
    session_id varchar(128),
    request_id int,
    transaction_id int,
    statement_id int,
    io_type varchar(128),
    projection_id int,
    projection_name varchar(128),
    anchor_table_id int,
    anchor_table_schema varchar(128),
    anchor_table_name varchar(128),
	batch_id integer
);
CREATE TABLE IF NOT EXISTS query_profiles
(
    session_id varchar(128),
    transaction_id int,
    statement_id int,
    identifier varchar(128),
    node_name varchar(128),
    query varchar(64000),
    query_search_path varchar(64000),
    schema_name varchar(128),
    table_name varchar(128),
    projections_used varchar(22),
    query_duration_us numeric(36,6),
    query_start_epoch int,
    query_start varchar(63),
    query_type varchar(128),
    error_code int,
    user_name varchar(128),
    processed_row_count int,
    reserved_extra_memory int,
    is_executing boolean,
	batch_id integer
);
CREATE TABLE IF NOT EXISTS resource_rejections
(
    node_name varchar(128),
    pool_id int,
    pool_name varchar(128),
    reason varchar(128),
    resource_type varchar(128),
    rejection_count int,
    first_rejected_timestamp timestamptz,
    last_rejected_timestamp timestamptz,
    last_rejected_value int,
	batch_id integer
);
CREATE TABLE IF NOT EXISTS system_resource_usage
(
    node_name varchar(128),
    end_time timestamp,
    average_memory_usage_percent float,
    average_cpu_usage_percent float,
    net_rx_kbytes_per_second float,
    net_tx_kbytes_per_second float,
    io_read_kbytes_per_second float,
    io_written_kbytes_per_second float,
	batch_id integer
);
CREATE TABLE IF NOT EXISTS user_sessions
(
    node_name varchar(128),
    user_name varchar(128),
    session_id varchar(128),
    transaction_id int,
    statement_id int,
    runtime_priority varchar(128),
    session_start_timestamp timestamptz,
    session_end_timestamp timestamptz,
    is_active boolean,
    client_hostname varchar(128),
    client_pid int,
    client_label varchar(64000),
    ssl_state varchar(128),
    authentication_method varchar(128),
    client_type varchar(128),
    client_version varchar(128),
    client_os varchar(128),
	batch_id integer
);