set SEARCH_PATH to vhist;

DROP TABLE IF EXISTS NODES_DIM CASCADE;
CREATE TABLE IF NOT EXISTS NODES_DIM
(
    node_key integer,	
    node_name varchar(128),
    node_id int,
    node_state varchar(128),
    node_address varchar(80),
    node_address_family varchar(10),
    export_address varchar(8192),
    export_address_family varchar(10),
    catalog_path varchar(8192),
    node_type varchar(9),
    is_ephemeral boolean,
    standing_in_for varchar(128),
    node_down_since timestamptz,
    valid_after_ts timestamp,
    valid_through_ts timestamp,
    is_current boolean,
    batch_id integer
);
insert into NODES_DIM(node_key,
	node_name ,
    node_id ,
    node_state ,
    node_address ,
    node_address_family ,
    export_address ,
    export_address_family ,
    catalog_path ,
    node_type ,
    is_ephemeral ,
    standing_in_for ,
    node_down_since ,
	valid_after_ts ,
	valid_through_ts ,
	is_current ,
	batch_id )  	
 values 	
        (1,
        'UNKNOWN', --  NODE_NAME	
        0,                     -- NODE_ID	
        'UNKNOWN', -- NODE_STATE	
        'UNKNOWN', -- NODE_ADDRESS	
		'UNKNOWN', -- NODE_ADDRESS_FAMILY
        'UNKNOWN', -- EXPORT_ADDRESS
		'UNKNOWN', -- EXPORT_ADDRESS_FAMILY
		'UNKNOWN', -- CATALOG_PATH
        'UNKNOWN', -- NODE_TYPE	
		false, 	   -- IS_EPHEMERAL
		'UNKNOWN', -- STANDING_IN_FOR
	    NULL, -- NODE_DOWN_SINCE
		'0001-01-01',
		NULL,
		true,
        0                       -- batch_id	
        );	
DROP TABLE IF EXISTS USERS_DIM CASCADE;
CREATE TABLE IF NOT EXISTS USERS_DIM
(
    user_key integer,
    user_name varchar(128),
    user_id int,
    is_super_user boolean,
    profile_name varchar(128),
    is_locked boolean,
    lock_time timestamptz,
    resource_pool varchar(128),
    memory_cap_kb varchar(20),
    temp_space_cap_kb varchar(20),
    run_time_cap varchar(63),
    all_roles varchar(8192),
    default_roles varchar(8192),
    search_path varchar(128),
    valid_after_ts timestamp,
    valid_through_ts timestamp,
    is_current boolean,
    batch_id integer
);
insert into userS_dim (user_key,user_name,user_id,is_super_user,profile_name ,is_locked,lock_time ,resource_pool , memory_cap_kb,temp_space_cap_kb ,run_time_cap , all_roles, default_roles,   search_path,	valid_after_ts,valid_through_ts,Is_current,	batch_id ) 	
 values 	
        (1,	
        'UNKNOWN', -- USER_NAME varchar(128),	
        0,  		-- USER_ID   integer,	
	false,
	'UNKNOWN',
	false,
	null,
	'UNKNOWN',
	'UNKNOWN', -- memory_cap_kb varchar(20),	
        'UNKNOWN', -- temp_space_cap_kb varchar(20),	
        'UNKNOWN', -- run_time_cap varchar(63),	
	'UNKNOWN',
	'UNKNOWN',
	'UNKNOWN',
	'0001-01-01',
	null,
	true,
        0 -- batch_id	
        );		
DROP TABLE IF EXISTS  SRU_FACT;	
CREATE TABLE if not exists SRU_FACT	
(	
	sru_fact_key  Auto_Increment not null,
   	node_key integer not null,	
    end_timestamp timestamp,	
    end_date_key integer,	
    end_time_key integer,	
    average_memory_usage_percent float,	
    average_cpu_usage_percent   float,	
    net_rx_kbytes_per_second        float,	
    net_tx_kbytes_per_second        float,	
    io_read_kbytes_per_second     float,	
    io_written_kbytes_per_second float,	
    batch_id integer	
);
DROP TABLE IF EXISTS  USER_SESSIONS_FACT;	
CREATE TABLE if not exists USER_SESSIONS_FACT	
(	
	user_sessions_fact_key Auto_Increment not null,
    node_key integer not null,	
    user_key integer not null,	
    session_id varchar(128),	
    transaction_id int,	
    statement_id int,	
    session_start_date_key integer,	
    session_end_date_key integer,	
    session_start_time_key integer,	
    session_end_time_key integer,	
    session_start_timestamp timestamptz,	
    session_end_timestamp timestamptz,	
    client_hostname varchar(128),	
    client_pid int,	
    client_label varchar(64000),	
    ssl_state varchar(128),	
    authentication_method varchar(128),	
    client_type varchar(128),	
    client_version varchar(128),	
    client_os varchar(128),	
    SESSION_DURATION_US	integer,
    batch_id integer	
);	

DROP TABLE IF EXISTS  QUERY_PROFILES_FACT;	
CREATE TABLE if not exists QUERY_PROFILES_FACT	
(	
	query_profile_fact_key Auto_Increment not null,
    session_id varchar(128),	
    transaction_id int,	
    statement_id int,	
    identifier Varchar(128),
    node_key integer not null,	
    query varchar(64000),	
    query_search_path varchar(64000),	
    schema_name varchar(128),	
    table_name varchar(128),	
    projections_used varchar(22),	
    query_duration_us numeric(36,6),	
    query_start_epoch int,	
    query_start_date_key integer,
	query_start_time_key integer,
    query_start_timestamp TIMESTAMP,
    query_type varchar(128),	
    error_code int,	
    user_key integer not null,	
    processed_row_count int,	
    reserved_extra_memory int,	
is_executing Boolean,
    batch_id integer	
    );
DROP TABLE IF EXISTS  LOAD_STREAMS_FACT;	
CREATE TABLE if not exists LOAD_STREAMS_FACT	
(	
	load_streams_fact_key Auto_Increment not null,
    session_id varchar(128),	
    transaction_id int,	
    statement_id int,	
    stream_name varchar(128),	
    schema_name varchar(128),	
    table_id int,	
    table_name varchar(128),	
    load_start_date_key integer,	
	load_start_time_key integer,
    load_start_timestamp timestamp,	
    load_duration_ms numeric(54,0),	
    is_executing boolean,  -- do not etl tuples while they are executing	
    accepted_row_count int,	
    rejected_row_count int,	
    read_bytes int,	
    input_file_size_bytes int,	
    parse_complete_percent int,	
    unsorted_row_count int,	
    sorted_row_count int,	
    sort_complete_percent int,	
    batch_id integer	
);	
DROP TABLE IF EXISTS  DISK_STORAGE_FACT;	
CREATE TABLE if not exists DISK_STORAGE_FACT	
(	
    disk_storage_fact_key Auto_Increment not null,
	node_key INTEGER not null,
load_timestamp timestamp,
load_date_key int,
load_time_key int,	
    storage_path varchar(8192),	
    storage_usage varchar(8192),	
    rank int,	
    throughput int,	
    latency int,	
    storage_status varchar(80),	
    disk_block_size_bytes int,	
    disk_space_used_blocks int,	
    disk_space_used_mb int,	
    disk_space_free_blocks int,	
    disk_space_free_mb int,	
    disk_space_free_percent varchar(80),	
    batch_id integer	
 );	
DROP TABLE IF EXISTS  RESOURCE_REJECTIONS_FACT;	
CREATE TABLE if not exists RESOURCE_REJECTIONS_FACT	
(	
    resource_rejections_fact_key Auto_Increment not null,
	node_key INTEGER not null,	
    pool_id int,	
    pool_name varchar(128),	
    reason varchar(128),	
    resource_type varchar(128),	
    rejection_count int,	
    first_rejected_date_key integer,	
    last_rejected_date_key integer,	
    first_rejected_time_key integer,	
    last_rejected_time_key integer,	
    first_rejected_timestamp timestamptz,	
    last_rejected_timestamp timestamptz,	
    last_rejected_value int,	
    batch_id integer	
 );	
DROP TABLE IF EXISTS  PROJECTION_USAGE_FACT;	
CREATE TABLE if not exists PROJECTION_USAGE_FACT	
(	
	projection_usage_fact_key Auto_Increment not null,
    QUERY_START_DATE_KEY integer,	
    QUERY_START_TIME_KEY integer,	
    QUERY_START_TIMESTAMP timestamp,	
    node_key integer not null,	
    user_key integer not null,	
                    session_id varchar(128),	
                    request_id int,	
                    transaction_id int,	
                    statement_id int,	
                    io_type varchar(128),	
                    projection_id int,	
                    projection_name varchar(128),	
                    anchor_table_id int,	
                    anchor_table_schema varchar(128),	
                    anchor_table_name varchar(128),	
                    batch_id integer	
);	
DROP TABLE IF EXISTS  vhist.PROJECTION_STORAGE_FACT;	
CREATE TABLE if not exists vhist.PROJECTION_STORAGE_FACT	
(	
		    projection_storage_fact_key Auto_Increment not null,
   		    load_timestamp timestamp,
		    load_date_key int,
		    load_time_key int,
                    node_key Integer not null,	
                    projection_id int,	
                    projection_name varchar(128),	
                    projection_schema varchar(128),	
                    projection_column_count int,	
                    row_count int,	
                    used_bytes int,	
                    wos_row_count int,	
                    wos_used_bytes int,	
                    ros_row_count int,	
                    ros_used_bytes int,	
                    ros_count int,	
                    anchor_table_name varchar(128),	
                    anchor_table_schema varchar(128),	
                    anchor_table_id int,	
                    batch_id integer	
);	